@@ -63,6 +63,22 @@
 #define	USB_MAX_FW_LENGTH	32768
 #endif
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,4,20)
+#define	DEVREQUEST		devrequest
+#define	DR_REQUEST_TYPE		requesttype
+#define	DR_REQUEST		request
+#define	DR_VALUE		value
+#define	DR_INDEX		index
+#define	DR_LENGTH		length
+#else
+#define	DEVREQUEST		struct usb_ctrlrequest
+#define	DR_REQUEST_TYPE		bRequestType
+#define	DR_REQUEST		bRequest
+#define	DR_VALUE		wValue
+#define	DR_INDEX		wIndex
+#define	DR_LENGTH		wLength
+#endif
+
 static char *			invalid_msg	= "Invalid appl id #%d.\n";
 
 /*---------------------------------------------------------------------------*\
@@ -174,25 +190,25 @@ static struct sk_buff * make_0xfe_request (unsigned appl) {
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
-static void config_completion (purb_t urb) {
-	devrequest * req;
+static void config_completion (struct urb * purb) {
+	DEVREQUEST * req;
 
-	assert (NULL != urb);
-	assert (0 == urb->status);
+	assert (NULL != purb);
+	assert (0 == purb->status);
 	log ("Completed SET_CONFIGURATION(0)\n");
-	req = (devrequest *) urb->context;
+	req = (DEVREQUEST *) purb->context;
 	hfree (req);
-	usb_free_urb (urb);
+	usb_free_urb (purb);
 } /* config_completion */
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
 static int reset (struct usb_device * dev) {
-	devrequest *	req;
-	purb_t 		purb;
+	DEVREQUEST *	req;
+	struct urb *	purb;
 	int		res;
 
-	if (NULL == (req = (devrequest *) hmalloc (sizeof (devrequest)))) {
+	if (NULL == (req = (DEVREQUEST *) hmalloc (sizeof (DEVREQUEST)))) {
 		error ("Not enough memory for device request!\n");
 		return -ENOMEM;
 	}
@@ -201,11 +217,11 @@ static int reset (struct usb_device * dev) {
 		hfree (req);
 		return -ENOMEM;
 	}
-	req->requesttype = 0;
-	req->request     = USB_REQ_SET_CONFIGURATION;
-	req->value       = 0;	/* Little endian required here! */ 
-	req->index       = 0;	/* Little endian required here! */
-	req->length      = 0;	/* Little endian required here! */
+	req->DR_REQUEST_TYPE = 0;
+	req->DR_REQUEST      = USB_REQ_SET_CONFIGURATION;
+	req->DR_VALUE        = 0;	/* Little endian required here! */ 
+	req->DR_INDEX        = 0;	/* Little endian required here! */
+	req->DR_LENGTH       = 0;	/* Little endian required here! */
 	FILL_CONTROL_URB (
 		purb,
 		dev,
@@ -1143,7 +1159,7 @@ static void issue_hard_error (dev_context_p pdc, const char * msg, int arg) {
 static void tx_dpc (void * data) {
 	static void	usb_write (dev_context_p, unsigned long);
 	dev_context_p	pdc;
-	purb_t		purb;
+	struct urb *	purb;
 	
 	assert (data);
 	pdc = (dev_context_p) data;
@@ -1174,7 +1190,7 @@ static void tx_dpc (void * data) {
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/ 
-static void usb_write_completion (purb_t purb) {
+static void usb_write_completion (struct urb * purb) {
 
 	UNUSED_ARG (purb);
 	kick_queue (&tq_tx_dpc);
@@ -1210,7 +1226,7 @@ static void usb_write (dev_context_p pdc, unsigned long len) {
 \*---------------------------------------------------------------------------*/ 
 static void rx_dpc (void * data) {
 	dev_context_p	pdc;
-	purb_t		purb;
+	struct urb *	purb;
 
 	assert (data);
 	pdc = (dev_context_p) data;
@@ -1235,7 +1251,7 @@ static void rx_dpc (void * data) {
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/ 
-static void usb_read_completion (purb_t purb) {
+static void usb_read_completion (struct urb * purb) {
 
 	UNUSED_ARG (purb);
 	kick_queue (&tq_rx_dpc);
